==> haskell-text-icu-0.7.0.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-icu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-GtbFFRs9sVugfs7GP5C1y
key: text-icu-0.7.0.1-GtbFFRs9sVugfs7GP5C1y
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
exposed: True
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
abi: 06080aee40b523b29468ef125bdfe243
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-icu-0.7.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-GtbFFRs9sVugfs7GP5C1y
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-icu-0.7.0.1-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-icu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-9QrjjiOgro6L8O3YDKMSJd
key: text-icu-0.7.0.1-9QrjjiOgro6L8O3YDKMSJd
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
exposed: True
indefinite: False
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
abi: d4faf84122c7c9176a18aa5a178bb9cf
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/text-icu-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-9QrjjiOgro6L8O3YDKMSJd
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.10.0.0 bytestring-0.10.8.2 deepseq-1.4.3.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
